==> tuia-advert-center-api-1.5.9-20180715.063316-5-sources.jar: cn/com/duiba/tuia/core/api/dto/AccountStatisticsDayDto.java <==
/**
 * 文件名： AdvertiserStatisticsDayDto.java 此类描述的是： 作者:xiawei 创建时间: 2016年9月05日 下午15:59:05
 */
package cn.com.duiba.tuia.core.api.dto;

import java.io.Serializable;

/**
 * 账户统计信息.
 *
 * @author: xaiwei
 * @version:
 */
public class AccountStatisticsDayDto implements Serializable {

    /** The Constant serialVersionUID. @since JDK 1.6 */
    private static final long serialVersionUID = -3970989645353641061L;

    /** 广告主Id. */
    private Long              id;

    /** 账户名称. */
    private String            name;

    /** 发券量. */
    private Integer           launchCount;

    /** 曝光量. */
    private Integer           exposureCount;

    /** 点击数. */
    private Integer           clickCount;

    /** 有效点击. */
    private Integer           efClickCount;

    /** 点击率. */
    private Float             clickRate;

    /** 花费. */
    private Long              consumeTotal;

    /** 点击均价. */
    private Integer           averagePrice;

    /**
     * id.
     *
     * @return the id
     * @since JDK 1.6
     */
    public Long getId() {
        return id;
    }

    /**
     * id.
     *
     * @param id the id to set
     * @since JDK 1.6
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * name.
     *
     * @return the name
     * @since JDK 1.6
     */
    public String getName() {
        return name;
    }

    /**
     * name.
     *
     * @param name the name to set
     * @since JDK 1.6
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * launchCount.
     *
     * @return the launchCount
     * @since JDK 1.6
     */
    public Integer getLaunchCount() {
        return launchCount;
    }

    /**
     * launchCount.
     *
     * @param launchCount the launchCount to set
     * @since JDK 1.6
     */
    public void setLaunchCount(Integer launchCount) {
        this.launchCount = launchCount;
    }

    /**
     * exposureCount.
     *
     * @return the exposureCount
     * @since JDK 1.6
     */
    public Integer getExposureCount() {
        return exposureCount;
    }

    /**
     * exposureCount.
     *
     * @param exposureCount the exposureCount to set
     * @since JDK 1.6
     */
    public void setExposureCount(Integer exposureCount) {
        this.exposureCount = exposureCount;
    }

    /**
     * clickCount.
     *
     * @return the clickCount
     * @since JDK 1.6
     */
    public Integer getClickCount() {
        return clickCount;
    }

    /**
     * clickCount.
     *
     * @param clickCount the clickCount to set
     * @since JDK 1.6
     */
    public void setClickCount(Integer clickCount) {
        this.clickCount = clickCount;
    }

    /**
     * efClickCount.
     *
     * @return the efClickCount
     * @since JDK 1.6
     */
    public Integer getEfClickCount() {
        return efClickCount;
    }

    /**
     * efClickCount.
     *
     * @param efClickCount the efClickCount to set
     * @since JDK 1.6
     */
    public void setEfClickCount(Integer efClickCount) {
        this.efClickCount = efClickCount;
    }

    /**
     * clickRate.
     *
     * @return the clickRate
     * @since JDK 1.6
     */
    public Float getClickRate() {
        return clickRate;
    }

    /**
     * clickRate.
     *
     * @param clickRate the clickRate to set
     * @since JDK 1.6
     */
    public void setClickRate(Float clickRate) {
        this.clickRate = clickRate;
    }

    /**
     * consumeTotal.
     *
     * @return the consumeTotal
     * @since JDK 1.6
     */
    public Long getConsumeTotal() {
        return consumeTotal;
    }

    /**
     * consumeTotal.
     *
     * @param consumeTotal the consumeTotal to set
     * @since JDK 1.6
     */
    public void setConsumeTotal(Long consumeTotal) {
        this.consumeTotal = consumeTotal;
    }

    /**
     * averagePrice.
     *
     * @return the averagePrice
     * @since JDK 1.6
     */
    public Integer getAveragePrice() {
        return averagePrice;
    }

    /**
     * averagePrice.
     *
     * @param averagePrice the averagePrice to set
     * @since JDK 1.6
     */
    public void setAveragePrice(Integer averagePrice) {
        this.averagePrice = averagePrice;
    }

    @Override
    public String toString() {
        StringBuilder builder = new StringBuilder();
        builder.append("AccountStatisticsDayDto [id=");
        builder.append(id);
        builder.append(", name=");
        builder.append(name);
        builder.append(", launchCount=");
        builder.append(launchCount);
        builder.append(", exposureCount=");
        builder.append(exposureCount);
        builder.append(", clickCount=");
        builder.append(clickCount);
        builder.append(", efClickCount=");
        builder.append(efClickCount);
        builder.append(", clickRate=");
        builder.append(clickRate);
        builder.append(", consumeTotal=");
        builder.append(consumeTotal);
        builder.append(", averagePrice=");
        builder.append(averagePrice);
        builder.append(", toString()=");
        builder.append(super.toString());
        builder.append("]");
        return builder.toString();
    }

}

==> tuia-advert-center-api-2.2.59-sources.jar: cn/com/duiba/tuia/core/api/dto/AccountStatisticsDayDto.java <==
/**
 * 文件名： AdvertiserStatisticsDayDto.java 此类描述的是： 作者:xiawei 创建时间: 2016年9月05日 下午15:59:05
 */
package cn.com.duiba.tuia.core.api.dto;

import java.io.Serializable;

/**
 * 账户统计信息.
 *
 * @author: xaiwei
 * @version:
 */
public class AccountStatisticsDayDto implements Serializable {

    /** The Constant serialVersionUID. @since JDK 1.6 */
    private static final long serialVersionUID = -3970989645353641061L;

    /** 广告主Id. */
    private Long              id;

    /** 账户名称. */
    private String            name;

    /** 发券量. */
    private Integer           launchCount;

    /** 曝光量. */
    private Integer           exposureCount;

    /** 点击数. */
    private Integer           clickCount;

    /** 有效点击. */
    private Integer           efClickCount;

    /** 点击率. */
    private Float             clickRate;

    /** 花费. */
    private Long              consumeTotal;

    /** 点击均价. */
    private Integer           averagePrice;

    // 上级代理商id
    private Long              agentId;

    public Long getAgentId() { return agentId; }

    public void setAgentId(Long agentId) { this.agentId = agentId; }

    /**
     * id.
     *
     * @return the id
     * @since JDK 1.6
     */
    public Long getId() {
        return id;
    }

    /**
     * id.
     *
     * @param id the id to set
     * @since JDK 1.6
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * name.
     *
     * @return the name
     * @since JDK 1.6
     */
    public String getName() {
        return name;
    }

    /**
     * name.
     *
     * @param name the name to set
     * @since JDK 1.6
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * launchCount.
     *
     * @return the launchCount
     * @since JDK 1.6
     */
    public Integer getLaunchCount() {
        return launchCount;
    }

    /**
     * launchCount.
     *
     * @param launchCount the launchCount to set
     * @since JDK 1.6
     */
    public void setLaunchCount(Integer launchCount) {
        this.launchCount = launchCount;
    }

    /**
     * exposureCount.
     *
     * @return the exposureCount
     * @since JDK 1.6
     */
    public Integer getExposureCount() {
        return exposureCount;
    }

    /**
     * exposureCount.
     *
     * @param exposureCount the exposureCount to set
     * @since JDK 1.6
     */
    public void setExposureCount(Integer exposureCount) {
        this.exposureCount = exposureCount;
    }

    /**
     * clickCount.
     *
     * @return the clickCount
     * @since JDK 1.6
     */
    public Integer getClickCount() {
        return clickCount;
    }

    /**
     * clickCount.
     *
     * @param clickCount the clickCount to set
     * @since JDK 1.6
     */
    public void setClickCount(Integer clickCount) {
        this.clickCount = clickCount;
    }

    /**
     * efClickCount.
     *
     * @return the efClickCount
     * @since JDK 1.6
     */
    public Integer getEfClickCount() {
        return efClickCount;
    }

    /**
     * efClickCount.
     *
     * @param efClickCount the efClickCount to set
     * @since JDK 1.6
     */
    public void setEfClickCount(Integer efClickCount) {
        this.efClickCount = efClickCount;
    }

    /**
     * clickRate.
     *
     * @return the clickRate
     * @since JDK 1.6
     */
    public Float getClickRate() {
        return clickRate;
    }

    /**
     * clickRate.
     *
     * @param clickRate the clickRate to set
     * @since JDK 1.6
     */
    public void setClickRate(Float clickRate) {
        this.clickRate = clickRate;
    }

    /**
     * consumeTotal.
     *
     * @return the consumeTotal
     * @since JDK 1.6
     */
    public Long getConsumeTotal() {
        return consumeTotal;
    }

    /**
     * consumeTotal.
     *
     * @param consumeTotal the consumeTotal to set
     * @since JDK 1.6
     */
    public void setConsumeTotal(Long consumeTotal) {
        this.consumeTotal = consumeTotal;
    }

    /**
     * averagePrice.
     *
     * @return the averagePrice
     * @since JDK 1.6
     */
    public Integer getAveragePrice() {
        return averagePrice;
    }

    /**
     * averagePrice.
     *
     * @param averagePrice the averagePrice to set
     * @since JDK 1.6
     */
    public void setAveragePrice(Integer averagePrice) {
        this.averagePrice = averagePrice;
    }

    @Override
    public String toString() {
        StringBuilder builder = new StringBuilder();
        builder.append("AccountStatisticsDayDto [id=");
        builder.append(id);
        builder.append(", name=");
        builder.append(name);
        builder.append(", launchCount=");
        builder.append(launchCount);
        builder.append(", exposureCount=");
        builder.append(exposureCount);
        builder.append(", clickCount=");
        builder.append(clickCount);
        builder.append(", efClickCount=");
        builder.append(efClickCount);
        builder.append(", clickRate=");
        builder.append(clickRate);
        builder.append(", consumeTotal=");
        builder.append(consumeTotal);
        builder.append(", averagePrice=");
        builder.append(averagePrice);
        builder.append(", toString()=");
        builder.append(super.toString());
        builder.append("]");
        return builder.toString();
    }

}
